# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.1] - 2023-11-03

### Added
- aBLT async API
- added few tests to cover the async API

## [0.0.2] - 2023-11-20

### Added
- aBLT sync API
- added few tests to cover the sync API
